km3pipe.io.HDF5Pump
===================

.. currentmodule:: km3pipe.io

.. autoclass:: HDF5Pump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HDF5Pump.__init__
      ~HDF5Pump.add
      ~HDF5Pump.close
      ~HDF5Pump.close_file
      ~HDF5Pump.configure
      ~HDF5Pump.expose
      ~HDF5Pump.finish
      ~HDF5Pump.get
      ~HDF5Pump.get_blob
      ~HDF5Pump.next
      ~HDF5Pump.open_file
      ~HDF5Pump.pre_finish
      ~HDF5Pump.process
      ~HDF5Pump.require
      ~HDF5Pump.rewind_file
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HDF5Pump.name
   
   